@@ -27,8 +27,8 @@ leaflet_sf <- function(x,
                        maxpoints,
                        ...) {
 
-  if (inherits(st_geometry(x), "sfc_MULTIPOINT"))
-    x = suppressWarnings(st_cast(x, "POINT"))
+  if (inherits(sf::st_geometry(x), "sfc_MULTIPOINT"))
+    x = suppressWarnings(sf::st_cast(x, "POINT"))
 
   if (is.null(layer.name)) layer.name = makeLayerName(x, zcol)
   cex <- circleRadius(x, cex)
@@ -37,6 +37,7 @@ leaflet_sf <- function(x,
     label = makeLabels(x, zcol)
   }
   if (!is.null(zcol)) {
+    if (inherits(x[[zcol]], "logical")) x[[zcol]] = as.character(x[[zcol]])
     if (length(unique(x[[zcol]])) == 1) {
       color = ifelse(is.function(color), standardColor(x), color)
       col.regions = ifelse(is.function(col.regions), standardColRegions(x), col.regions)
@@ -186,29 +187,29 @@ leaflet_sfc <- function(x,
     pane = NULL
   }
 
-  m <- addFeatures(m,
-                   data = x,
-                   pane = pane,
-                   radius = cex,
-                   weight = lwd,
-                   opacity = alpha,
-                   fillOpacity = alpha.regions,
-                   color = color,
-                   fillColor = col.regions,
-                   popup = popup,
-                   label = label,
-                   group = layer.name,
-                   highlightOptions = highlight,
-                   ...)
+  m <- leafem::addFeatures(m,
+                           data = x,
+                           pane = pane,
+                           radius = cex,
+                           weight = lwd,
+                           opacity = alpha,
+                           fillOpacity = alpha.regions,
+                           color = color,
+                           fillColor = col.regions,
+                           popup = popup,
+                           label = label,
+                           group = layer.name,
+                           highlightOptions = highlight,
+                           ...)
 
   if (!is.null(map)) m = updateOverlayGroups(m, layer.name)
   sclbrpos = getCallEntryFromMap(m, "addScaleBar")
   if (length(sclbrpos) > 0 | native.crs) scalebar = FALSE else scalebar = TRUE
 
   funs <- list(if (scalebar) leaflet::addScaleBar,
-               if (homebutton) addHomeButton,
+               if (homebutton) leafem::addHomeButton,
                if (is.null(map)) mapViewLayersControl,
-               addMouseCoordinates)
+               leafem::addMouseCoordinates)
   funs <- funs[!sapply(funs, is.null)]
 
   args <- list(if (scalebar) list(position = "bottomleft"),
@@ -228,7 +229,7 @@ leaflet_sfc <- function(x,
                    args = args)
 
   try(
-    if (attributes(popup)$popup == "mapview") {
+    if (attributes(popup)$popup == "leafpop") {
       m$dependencies <- c(m$dependencies, popupLayoutDependencies())
     }
     , silent = TRUE
